@@ -10,12 +10,14 @@ package Devel::Cover;
 use strict;
 use warnings;
 
-our $VERSION = '1.02'; # VERSION
+our $VERSION = '1.04'; # VERSION
 our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 use DynaLoader ();
 our @ISA = "DynaLoader";
 
+# sub Pod::Coverage::TRACE_ALL () { 1 }
+
 use Devel::Cover::DB;
 use Devel::Cover::DB::Digests;
 use Devel::Cover::Inc;
@@ -579,6 +581,11 @@ sub use_file
 
     # die "bad file" unless length $file;
 
+    # If you call your file something that matches $find_filename then things
+    # might go awry.  But it would be silly to do that, so don't.  This little
+    # optimisation provides a reasonable speedup.
+    return $Files{$file} if exists $Files{$file};
+
     # just don't call your filenames 0
     while ($file =~ $find_filename) { $file = $1 || $2 || $3 || $4 }
     $file =~ s/ \(autosplit into .*\)$//;
@@ -637,7 +644,8 @@ sub B::GV::find_cv
         $cv->PADLIST->ARRAY &&
         $cv->PADLIST->ARRAY->can("ARRAY"))
     {
-        $Cvs{$_} ||= $_ for grep check_file($_), $cv->PADLIST->ARRAY->ARRAY;
+        $Cvs{$_} ||= $_
+          for grep ref eq "B::CV" && check_file($_), $cv->PADLIST->ARRAY->ARRAY;
     }
 };
 
@@ -1048,6 +1056,8 @@ sub deparse
         # print STDERR "[$Seen{statement}{$$op}] [$Seen{other}{$$op}]\n";
         # use Carp "cluck"; cluck("from here");
 
+        return "" if $name eq "padrange";
+
         unless ($Seen{statement}{$$op} || $Seen{other}{$$op}) {
             # Collect everything under here.
             local ($File, $Line) = ($File, $Line);
@@ -1286,21 +1296,24 @@ sub get_cover
                 }
             }
             $Pod = "Pod::Coverage" if delete $opts{nocp};
-            # print STDERR "$Pod, ", Dumper \%opts;
-            if ($Pod{$file} ||= $Pod->new(package => $pkg, %opts))
+            # print STDERR "$Pod, $File:$Line ($Sub_name) [$file($pkg)]",
+            #              Dumper \%opts;
+            if ($Pod{$pkg} ||= $Pod->new(package => $pkg, %opts))
             {
+                # print STDERR Dumper $Pod{$file};
                 my $covered;
-                for ($Pod{$file}->covered)
+                for ($Pod{$pkg}->covered)
                 {
                     $covered = 1, last if $_ eq $Sub_name;
                 }
                 unless ($covered)
                 {
-                    for ($Pod{$file}->uncovered)
+                    for ($Pod{$pkg}->uncovered)
                     {
                         $covered = 0, last if $_ eq $Sub_name;
                     }
                 }
+                # print STDERR "covered ", $covered // "undef", "\n";
                 if (defined $covered)
                 {
                     my ($n, $new) = $Structure->add_count("pod");
@@ -1346,7 +1359,7 @@ Devel::Cover - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.02
+version 1.04
 
 =head1 SYNOPSIS
 
